@@ -3,7 +3,7 @@ import json
 import pathlib
 import collections
 
-from csvw.dsv import reader
+from csvw.dsv import reader, Dialect
 import requests
 from clldutils.misc import nfilter
 
@@ -19,9 +19,13 @@ URL = 'http://chirila.yale.edu/languages'
 
 class AIATSIS(LinkProvider):
     def iterupdated(self, languoids):  # pragma: no cover
-        res = reader(io.StringIO(requests.get(MD_URL).content.decode('utf-8-sig')), dicts=True)
+        res = reader(
+            io.StringIO(requests.get(MD_URL).content.decode('utf-8-sig')),
+            dialect=Dialect(skipBlankRows=True, commentPrefix='<'),
+            dicts=True)
         md = {d['language_code']: d for d in res}
         lmap = collections.defaultdict(set)
+        return
         for line in requests.get(URL).text.splitlines():
             if line.startswith('var curItem'):
                 line = line.split('=', maxsplit=1)[1]
@@ -41,15 +45,15 @@ class AIATSIS(LinkProvider):
                     continue
                 lmap[gc].add(code)
 
-        for l in languoids:
+        for lang in languoids:
             links, names = [], []
-            for c in sorted(lmap.get(l.id, [])):
+            for c in sorted(lmap.get(lang.id, [])):
                 links.append((md[c]['uri'], md[c]['language_name']))
                 if md[c]['language_name']:
                     names.append(md[c]['language_name'])
                 names.extend(nfilter([n.strip() for n in md[c]['language_synonym'].split('|')]))
             if any([
-                l.update_links(DOMAIN, links),
-                l.update_names(names, type_='aiatsis'),
+                lang.update_links(DOMAIN, links),
+                lang.update_names(names, type_='aiatsis'),
             ]):
-                yield l
+                yield lang
