@@ -6,7 +6,7 @@ import unicodedata
 import datetime
 import math
 import functools
-from pathlib import Path
+import pathlib
 
 import attr
 
@@ -24,27 +24,29 @@ from .bibfiles_db import Database
 __all__ = ['BibFiles', 'BibFile', 'Entry']
 
 ATTRS_VERSION = tuple(int(v) for v in getattr(attr, '__version__', '20.1').split('.'))
+
 BIBFILES = 'bibfiles.sqlite3'
-DOCTYPES = collections.OrderedDict((k, k) for k in [
-    'grammar',
-    'grammar_sketch',
-    'dictionary',
-    'specific_feature',
-    'phonology',
-    'text',
-    'new_testament',
-    'wordlist',
-    'comparative',
-    'minimal',
-    'socling',
-    'dialectology',
-    'overview',
-    'ethnographic',
-    'bibliographical',
-    'unknown',
-])
-PREF_YEAR_PATTERN = re.compile('\[(?P<year>(1|2)[0-9]{3})(\-[0-9]+)?\]')
-YEAR_PATTERN = re.compile('(?P<year>(1|2)[0-9]{3})')
+
+DOCTYPES = {k: k for k in ['grammar',
+                           'grammar_sketch',
+                           'dictionary',
+                           'specific_feature',
+                           'phonology',
+                           'text',
+                           'new_testament',
+                           'wordlist',
+                           'comparative',
+                           'minimal',
+                           'socling',
+                           'dialectology',
+                           'overview',
+                           'ethnographic',
+                           'bibliographical',
+                           'unknown']}
+
+PREF_YEAR_PATTERN = re.compile(r'\[(?P<year>(1|2)[0-9]{3})(\-[0-9]+)?\]')
+
+YEAR_PATTERN = re.compile(r'(?P<year>(1|2)[0-9]{3})')
 
 
 class BibFiles(list):
@@ -53,8 +55,8 @@ class BibFiles(list):
     @classmethod
     def from_path(cls, path, api=None):
         """BibTeX files from `<path>/bibtex/*.bib` if listed in `<path>/BIBFILES.ini`."""
-        if not isinstance(path, Path):
-            path = Path(path)
+        if not isinstance(path, pathlib.Path):
+            path = pathlib.Path(path)
         ini = INI.from_file(path / 'BIBFILES.ini', interpolation=None)
         return cls(cls._iterbibfiles(ini, path / 'bibtex', api=api))
 
@@ -68,14 +70,22 @@ class BibFiles(list):
                 yield BibFile(fname=fpath, api=api, **ini[sec])
 
     def __init__(self, bibfiles):
-        super(BibFiles, self).__init__(bibfiles)
+        super().__init__(bibfiles)
         self._map = {b.fname.name: b for b in self}
 
     def __getitem__(self, index_or_filename):
-        """Retrieve a bibfile by index or filename."""
+        """Retrieve a bibfile by index or filename or an entry by qualified key.
+
+        :param index_or_filename: Either an `int` index, or a bibfile name, or a \
+        provider-qualified BibTeX key in the form `<prov>:<key>`.
+        :return: A `BibFile` instance, or an `Entry` instance.
+        """
         if isinstance(index_or_filename, str):
+            if ':' in index_or_filename:
+                stem, key = index_or_filename.split(':', maxsplit=1)
+                return self._map['{}.bib'.format(stem)][key]
             return self._map[index_or_filename]
-        return super(BibFiles, self).__getitem__(index_or_filename)
+        return super().__getitem__(index_or_filename)
 
     def to_sqlite(self, filepath=BIBFILES, rebuild=False, verbose=False):
         """Return a database with the bibfiles loaded."""
@@ -106,6 +116,7 @@ class BibFile(object):
         converter=lambda s: None if s is None or s.lower() == 'none' else s)
     priority = attr.ib(default=0, converter=int)
     url = attr.ib(default=None)
+    curation = attr.ib(default=None)
     api = attr.ib(default=None)
 
     @property
@@ -117,7 +128,8 @@ class BibFile(object):
             item = item.split(':', 1)[1]
         text = None
         with memorymapped(self.fname) as string:
-            m = re.search(b'@[A-Za-z]+\{' + re.escape(item.encode(self.encoding)), string)
+            m = re.search(
+                b'@[A-Za-z]+{' + re.escape(item.encode(self.encoding)) + rb'[\s,]', string)
             if m:
                 next = string.find(b'\n@', m.end())
                 if next >= 0:
@@ -186,7 +198,7 @@ class BibFile(object):
             normalize=self.normalize)
 
     def __str__(self):
-        return '<%s %s>' % (self.__class__.__name__, self.fname.name)
+        return f'<{self.__class__.__name__} {self.fname.name}>'
 
     def check(self, log):
         entries = self.load()  # bare BibTeX syntax
@@ -223,9 +235,9 @@ class Entry(object):
 
     # FIXME: add method to apply triggers!
 
-    lgcode_regex = '[a-z0-9]{4}[0-9]{4}|[a-z]{3}|NOCODE_[A-Z][^\s\]]+'
-    lgcode_in_brackets_pattern = re.compile("\[(" + lgcode_regex + ")\]")
-    recomma = re.compile("[,/]\s?")
+    lgcode_regex = r'[a-z0-9]{4}[0-9]{4}|[a-z]{3}|NOCODE_[A-Z][^\s\]]+'
+    lgcode_in_brackets_pattern = re.compile(r"\[(" + lgcode_regex + r")]")
+    recomma = re.compile(r"[,/]\s?")
     lgcode_pattern = re.compile(lgcode_regex + "$")
 
     def __eq__(self, other):
@@ -255,8 +267,8 @@ class Entry(object):
 
         # the number of pages is divided by number of doctypes times number of described languages
         pages = int(math.ceil(
-            float(self.pages_int or 0) /
-            ((len(self.doctypes(doctypes)[0]) or 1) *
+            float(self.pages_int or 0) /  # noqa: W504
+            ((len(self.doctypes(doctypes)[0]) or 1) *  # noqa: W504
              (len(self.lgcodes(self.fields.get('lgcode', ''))) or 1))))
 
         if doctype == 'grammar' and pages >= 300:
@@ -311,9 +323,7 @@ class Entry(object):
         return p, self.fields.get('address')
 
     def __str__(self):
-        """
-        :return: BibTeX representation of the entry.
-        """
+        """Return the BibTeX representation of the entry."""
         res = "@%s{%s" % (self.type, self.key)
         for k, v in bibtex.fieldorder.itersorted(self.fields):
             res += ',\n    %s = {%s}' % (k, v.strip() if hasattr(v, 'strip') else v)
@@ -321,9 +331,7 @@ class Entry(object):
         return res
 
     def text(self):
-        """
-        :return: Text linearization of the entry.
-        """
+        """Return the text linearization of the entry."""
         return Source(self.type, self.key, _check_id=False, **self.fields).text()
 
     @property
@@ -359,8 +367,7 @@ class Entry(object):
         return res, self.parse_ca(self.fields.get('lgcode'))
 
     def doctypes(self, hhtypes):
-        """
-        Ordered doctypes assigned to this entry.
+        """Ordered doctypes assigned to this entry.
 
         :param hhtypes: `OrderedDict` mapping doctype names to doctypes
         :return: `list` of values of `hhtypes` which apply to the entry, ordered by occurrence in\
